Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
src/mcp_atlassian/__init__.py | 57 | 32 | 0 | 44%
src/mcp_atlassian/config.py | 19 | 19 | 0 | 0%
src/mcp_atlassian/confluence/__init__.py | 9 | 0 | 0 | 100%
src/mcp_atlassian/confluence/client.py | 12 | 0 | 0 | 100%
src/mcp_atlassian/confluence/comments.py | 33 | 4 | 0 | 88%
src/mcp_atlassian/confluence/config.py | 22 | 0 | 0 | 100%
src/mcp_atlassian/confluence/formatters.py | 0 | 0 | 0 | 100%
src/mcp_atlassian/confluence/pages.py | 67 | 5 | 0 | 93%
src/mcp_atlassian/confluence/search.py | 29 | 2 | 0 | 93%
src/mcp_atlassian/confluence/spaces.py | 52 | 6 | 0 | 88%
src/mcp_atlassian/document_types.py | 6 | 0 | 0 | 100%
src/mcp_atlassian/jira/__init__.py | 16 | 0 | 0 | 100%
src/mcp_atlassian/jira/client.py | 28 | 3 | 0 | 89%
src/mcp_atlassian/jira/comments.py | 45 | 4 | 0 | 91%
src/mcp_atlassian/jira/config.py | 41 | 1 | 0 | 98%
src/mcp_atlassian/jira/epics.py | 196 | 42 | 0 | 79%
src/mcp_atlassian/jira/fields.py | 129 | 14 | 0 | 89%
src/mcp_atlassian/jira/formatting.py | 126 | 4 | 0 | 97%
src/mcp_atlassian/jira/issues.py | 326 | 91 | 0 | 72%
src/mcp_atlassian/jira/projects.py | 166 | 3 | 0 | 98%
src/mcp_atlassian/jira/search.py | 93 | 5 | 0 | 95%
src/mcp_atlassian/jira/transitions.py | 84 | 0 | 0 | 100%
src/mcp_atlassian/jira/users.py | 63 | 4 | 0 | 94%
src/mcp_atlassian/jira/utils.py | 0 | 0 | 0 | 100%
src/mcp_atlassian/jira/worklog.py | 81 | 3 | 0 | 96%
src/mcp_atlassian/preprocessing.py | 239 | 64 | 0 | 73%
src/mcp_atlassian/server.py | 380 | 297 | 0 | 22%
Total | 2319 | 603 | 0 | 74%

No items found using the specified filter.